@@ -530,7 +530,7 @@ class BeforeTestExecutionPayload(Payload):
     method: str = attr.ib()
     path: str = attr.ib()
     relative_path: str = attr.ib()
-    categories: list[str] = attr.ib()
+    categories: list[str] = attr.ib(factory=list)
     test_suite_id: Optional[str] = attr.ib(default=None)
     description: Optional[str] = attr.ib(default=None)
 
