@@ -24,7 +24,7 @@ def test_config():
             "api_key": None,
             "token": None,
         },
-        "module_specific_config": {},
+        "module_providers": {},
         "runner_log_handler": None,
         "test_case_log_handler": None,
     }
